@@ -42,6 +42,8 @@ MainWindow::MainWindow(QWidget *parent)
     : QMainWindow(parent), ui(new Ui::MainWindow)
 {
     SetSigned(UNSIGNED);
+    SetNumBits(NUMBITS_32);
+    SetRegister(REG_A);
     ui->setupUi(this);
 
     ui->buttonGroup->setId(ui->pushButton_bit1, 1);
@@ -156,6 +158,7 @@ void MainWindow::UpdateDisplay()
     {
     updatingDisplay = true;
 
+
     int value = GetValue(REG_CURRENT);
 
     char str[128];
@@ -174,9 +177,10 @@ void MainWindow::UpdateDisplay()
     sprintf(str, "%X", value);
     ui->lineEdit_hex->setText(str);
 
-    ui->radioButton_8bit-> setChecked(false);
+    /*ui->radioButton_8bit-> setChecked(false);
     ui->radioButton_16bit->setChecked(false);
     ui->radioButton_32bit->setChecked(false);
+
     switch (GetNumBits())
     {
         case NUMBITS_8:  ui->radioButton_8bit-> setChecked(true); break;
@@ -184,22 +188,22 @@ void MainWindow::UpdateDisplay()
         case NUMBITS_32: ui->radioButton_32bit->setChecked(true); break;
     }
 
-    ui->pushButton_registerA->setChecked(false);
-    ui->pushButton_registerB->setChecked(false);
-    ui->pushButton_registerC->setChecked(false);
+    ui->radioButton_registerA->setChecked(false);
+    ui->radioButton_registerB->setChecked(false);
+    ui->radioButton_registerC->setChecked(false);
     switch (GetRegister())
     {
     default:
     case REG_A:
-        ui->pushButton_registerA->setChecked(true);
+        ui->radioButton_registerA->setChecked(true);
         break;
     case REG_B:
-        ui->pushButton_registerB->setChecked(true);
+        ui->radioButton_registerB->setChecked(true);
         break;
     case REG_C:
-        ui->pushButton_registerC->setChecked(true);
+        ui->radioButton_registerC->setChecked(true);
         break;
-    }
+    }*/
 
     sprintf(str, "%d", (unsigned char)((value & 0x000000FF) >> 0));
     ui->lineEdit_ipaddress0->setText(str);
@@ -273,9 +277,7 @@ void MainWindow::UpdateDisplay()
             {
                 ui->buttonGroup->button(i+16)->setText("");
             }
-            ui->lineEdit_hex->setMaxLength(4);
-            if (ui->checkBox_signed->checkState()) ui->lineEdit_dec->setMaxLength(6);
-            else ui->lineEdit_dec->setMaxLength(5);
+
 
             ui->frame_bit32->setDisabled(true);
 
@@ -292,9 +294,6 @@ void MainWindow::UpdateDisplay()
         {
             ui->buttonGroup->button(i+8)->setText("");
         }
-        ui->lineEdit_hex->setMaxLength(2);
-        if (ui->checkBox_signed->checkState()) ui->lineEdit_dec->setMaxLength(4);
-        else ui->lineEdit_dec->setMaxLength(3);
 
         ui->frame_bit16->setDisabled(true);
         ui->frame_bit32->setDisabled(true);
@@ -370,6 +369,9 @@ void MainWindow::on_radioButton_8bit_clicked()
 {
     SetNumBits(NUMBITS_8);
     UpdateDisplay();
+    ui->lineEdit_hex->setMaxLength(2);
+    if (ui->checkBox_signed->checkState()) ui->lineEdit_dec->setMaxLength(4);
+    else ui->lineEdit_dec->setMaxLength(3);
 }
 
 /****************************************************************************
@@ -386,6 +388,9 @@ void MainWindow::on_radioButton_16bit_clicked()
 {
     SetNumBits(NUMBITS_16);
     UpdateDisplay();
+    ui->lineEdit_hex->setMaxLength(4);
+    if (ui->checkBox_signed->checkState()) ui->lineEdit_dec->setMaxLength(6);
+    else ui->lineEdit_dec->setMaxLength(5);
 }
 
 /****************************************************************************
@@ -402,6 +407,9 @@ void MainWindow::on_radioButton_32bit_clicked()
 {
     SetNumBits(NUMBITS_32);
     UpdateDisplay();
+    ui->lineEdit_hex->setMaxLength(8);
+    if (ui->checkBox_signed->checkState()) ui->lineEdit_dec->setMaxLength(11);
+    else ui->lineEdit_dec->setMaxLength(10);
 }
 /****************************************************************************
 
@@ -439,7 +447,25 @@ void MainWindow::on_checkBox_signed_toggled(bool isChecked)
         sig=UNSIGNED;
 
     SetSigned(sig);
+    if (isChecked)
+    {
+        switch (GetNumBits())
+        {
+            case NUMBITS_8:  ui->lineEdit_dec->setMaxLength(4); break;
+            case NUMBITS_16: ui->lineEdit_dec->setMaxLength(6); break;
+            case NUMBITS_32: ui->lineEdit_dec->setMaxLength(11); break;
+        }
+    }
     UpdateDisplay();
+    if (!isChecked)
+    {
+        switch (GetNumBits())
+        {
+            case NUMBITS_8:  ui->lineEdit_dec->setMaxLength(3); break;
+            case NUMBITS_16: ui->lineEdit_dec->setMaxLength(5); break;
+            case NUMBITS_32: ui->lineEdit_dec->setMaxLength(10); break;
+        }
+    }
 }
 
 /****************************************************************************
@@ -590,32 +616,30 @@ void MainWindow::on_pushButton_decrease_clicked()
 
     Qt Signal Handler
 
-    control:    pushButton_register[A|B|C]
-    signal:     pressed
+    control:    radioButton_register[A|B|C]
+    signal:     clicked
 
     Select the current register that is being displayed
 
 ****************************************************************************/
-void MainWindow::on_pushButton_registerA_pressed()
+void MainWindow::on_radioButton_registerA_clicked()
 {
     SetRegister(REG_A);
     UpdateDisplay();
 }
 
-void MainWindow::on_pushButton_registerB_pressed()
+void MainWindow::on_radioButton_registerB_clicked()
 {
     SetRegister(REG_B);
     UpdateDisplay();
 }
 
-void MainWindow::on_pushButton_registerC_pressed()
+void MainWindow::on_radioButton_registerC_clicked()
 {
     SetRegister(REG_C);
     UpdateDisplay();
 }
 
-
-
 /****************************************************************************
 
     This is the generic function to handle register operations after the user
@@ -632,6 +656,7 @@ int MainWindow::HandleOperation
 
     // change the display to show register C
     SetRegister(REG_C);
+    ui->radioButton_registerC->setChecked(true);
 
     // Update the display
     UpdateDisplay();
@@ -881,5 +906,5 @@ void MainWindow::on_lineEdit_ascii3_textChanged()
 }
 void MainWindow::about()
 {
-    QMessageBox::about(this,tr("HexTool Version 1.7.0.0"),tr("Ported and code changes by Halftux"));
+    QMessageBox::about(this,tr("HexTool Maemo Version 1.7.1"),tr("Ported and code changes by Halftux.\nBased on Version 1.7.0.0 by Ryan Harkin."));
 }
